#
# spec file for package coreboot-utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           coreboot-utils
Version:        24.08
Release:        1.1
Summary:        A universal flash programming utility
License:        GPL-2.0-only
Group:          Development/Tools/Other
URL:            https://coreboot.org/
Source0:        https://www.coreboot.org/releases/coreboot-%{version}.tar.xz
Source1:        https://www.coreboot.org/releases/coreboot-%{version}.tar.xz.sig
Source3:        %{name}.keyring
Patch1:         no-pie.patch
Patch3:         do-explicit-fallthrough.patch
BuildRequires:  gcc-c++
BuildRequires:  libopenssl-devel
BuildRequires:  pciutils-devel
BuildRequires:  xz
BuildRequires:  zlib-devel
ExclusiveArch:  %ix86 x86_64

%description
coreboot is a Free Software project aimed at replacing the proprietary BIOS
(firmware) found in most computers. This package contains various utilities
used to develop and configure systems with coreboot.

%prep
%autosetup -p1 -n coreboot-%{version}

%build
make %{?_smp_mflags} CFLAGS="%{optflags}" -C util/ectool
make %{?_smp_mflags} CC="cc %{optflags}" -C util/superiotool
make %{?_smp_mflags} CFLAGS="%{optflags} -DCMOS_HAL=1 -I." -C util/nvramtool
make %{?_smp_mflags} CFLAGS="%{optflags}" -C util/cbmem
make %{?_smp_mflags} CFLAGS="%{optflags} -I../../src/commonlib/include" -C util/ifdtool
%ifarch x86_64
make %{?_smp_mflags} -C util/cbfstool
%endif
%ifarch %{ix86} x86_64
CXXFLAGS="$CXXFLAGS -fPIC"
CFLAGS="$CFLAGS -fPIC"
make %{?_smp_mflags} CFLAGS="%{optflags}" -C util/inteltool
%ifarch x86_64
make %{?_smp_mflags} -C util/cbfstool
make %{?_smp_mflags} HOSTCC="cc %{optflags}"  -C util/amdfwtool
%endif
(cd util/msrtool && %configure && make %{?_smp_mflags} )
%endif

%install
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_datadir}
install -d %{buildroot}%{_mandir}/man1

make %{?_smp_mflags} PREFIX=%{buildroot}/%{_prefix} -C util/ectool install
make %{?_smp_mflags} DESTDIR=%{buildroot} PREFIX=%{_prefix} -C util/superiotool install
make %{?_smp_mflags} DESTDIR=%{buildroot} PREFIX=%{_prefix} -C util/nvramtool install
make %{?_smp_mflags} DESTDIR=%{buildroot} PREFIX=%{_prefix} -C util/intelmetool install

install util/ifdtool/ifdtool %{buildroot}%{_bindir}
install util/cbmem/cbmem %{buildroot}%{_bindir}
%ifarch %{ix86} x86_64
make %{?_smp_mflags} DESTDIR=%{buildroot} PREFIX=%{_prefix} -C util/inteltool install
make -C util/msrtool DESTDIR=%{buildroot} PREFIX=%{_prefix} install
%ifarch x86_64
install util/amdfwtool/amdfwtool %{buildroot}%{_sbindir}
install util/cbfstool/cbfstool %{buildroot}%{_bindir}
%endif
%endif

install -pm644 util/superiotool/README README.superiotool
install -pm644 util/superiotool/COPYING COPYING.superiotool
install -pm644 util/nvramtool/README README.nvramtool
install -pm644 util/nvramtool/COPYING COPYING.nvramtool
install -pm644 util/nvramtool/DISCLAIMER DISCLAIMER.nvramtool
%ifarch %{ix86} x86_64
install -pm644 util/msrtool/COPYING COPYING.msrtool
%endif

%files
%defattr(-,root,root)
%license COPYING.superiotool
%doc README.superiotool
%license COPYING.nvramtool
%doc README.nvramtool DISCLAIMER.nvramtool
%ifarch x86_64
%{_bindir}/cbfstool
%{_sbindir}/amdfwtool
%endif
%{_bindir}/cbmem
%{_bindir}/ifdtool
%{_sbindir}/ectool
%{_sbindir}/inteltool
%{_sbindir}/intelmetool
%{_sbindir}/msrtool
%{_sbindir}/nvramtool
%{_sbindir}/superiotool
%{_mandir}/man8/*

%changelog
* Sun Dec 22 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 24.08
  * https://coreboot.org/releases/coreboot-24.08-relnotes.txt
- Update to version 24.05
  * https://coreboot.org/releases/coreboot-24.05-relnotes.txt
- Update to version 24.02.01
  * https://coreboot.org/releases/coreboot-24.02.01-relnotes.txt
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Wed Nov 29 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 4.22.01
  Bugfix release
  * fixed an uninitialized variable error on the
    sandybridge/ivybridge platforms.
* Fri Nov 24 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 4.22
  * Full changelog:
  https://coreboot.org/releases/coreboot-4.22-relnotes.txt
* Tue Aug 29 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 4.21
  * Full changelog:
  https://coreboot.org/releases/coreboot-4.21-relnotes.txt
  https://coreboot.org/releases/coreboot-4.20-relnotes.txt
* Sat Feb  4 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 4.19
  * Full changelog:
  https://coreboot.org/releases/coreboot-4.19-relnotes.txt
* Sat Oct 22 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 4.18
  Changes since 4.10
  * https://coreboot.org/releases/coreboot-4.18-relnotes.txt
  * https://coreboot.org/releases/coreboot-4.17-relnotes.txt
  * https://coreboot.org/releases/coreboot-4.16-relnotes.txt
  * https://coreboot.org/releases/coreboot-4.15-relnotes.txt
  * https://coreboot.org/releases/coreboot-4.14-relnotes.txt
  * https://coreboot.org/releases/coreboot-4.13-relnotes.txt
  * https://coreboot.org/releases/coreboot-4.12-relnotes.txt
  * https://coreboot.org/releases/coreboot-4.11-relnotes.txt
- Upstream removed some tools:
  * util/k8resdump
  * util/romcc
  * util/viatool
- Drop not longer needed patches:
  * k8resdump.diff
  * msrtool-fix-build-with-gcc-10.patch
- Update coreboot-utils.keyring
  - > 574CE6F6855CFDEB7D368E9D19796C2B3E4F7DF7
    Martin Roth (coreboot developer) <martin@coreboot.org>
* Mon Jan 18 2021 Michal Suchanek <msuchanek@suse.de>
- Fix build with GCC 10
  * msrtool-fix-build-with-gcc-10.patch
* Sat Sep 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to 4.10
  * Full changelog:
    https://coreboot.org/releases/coreboot-4.10-relnotes.txt
- Update coreboot-utils.keyring
  Old key 0x269C04E1 got superseeded by 0xAA103F48728F5291
* Fri Dec 21 2018 mardnh@gmx.de
- Update to 4.9
  * Full changelog:
    https://coreboot.org/releases/coreboot-4.9-relnotes.txt
- Rebase patches:
  * no-pie.patch
- Update coreboot-utils.keyring
  Old key 0x19796C2B3E4F7DF7 got superseeded by 0x269C04E1
* Thu May 17 2018 mardnh@gmx.de
- Update to 4.8.1
  * Full changelog:
    https://www.coreboot.org/releases/coreboot-4.8.1-relnotes.txt
- Rebase patches:
  * no-pie.patch
* Mon Jan 15 2018 mardnh@gmx.de
- Update to 4.7
  * Full changelog:
    https://coreboot.org/releases/coreboot-4.7-relnotes.txt
- Rebase patches:
  * k8resdump.diff
  * no-pie.patch
  * do-explicit-fallthrough.patch
- Adjust CFLAGS for util/ifdtool
* Wed Jan  3 2018 mardnh@gmx.de
- verify source signature
* Fri Dec 29 2017 mardnh@gmx.de
- Update to 4.6
  * Full changelog:
    https://www.coreboot.org/releases/coreboot-4.6-relnotes.txt
- Fix URL
- Build with intelmetool
* Fri Jun 16 2017 alarrosa@suse.com
- Add do-explicit-fallthrough.patch to fix a build failure with gcc7
  with an implicit fallthrough over switch cases (only on TW)
- Add -fPIC to no-pie.patch and remove -fno-pic to build with gcc7
* Fri Mar 31 2017 meissner@suse.com
- no-pie.patch: build msrtool without PIE/PIC
* Sat Feb 25 2017 shshyukriev@suse.com
- Update to 4.5:
  Areas with significant updates:
    Toolchain (29 commits)
    Updated mpfr version from 3.1.3 to 3.1.4
    Updated gcc version from 5.2.0 to 5.3.0
    Updated binutils version from 2.25 to 2.26.1 & Fix aarch64 build problem
    Updated gdb version from 7.9.1 to 7.11
    Updated iasl version from 20160318 to 20160831
    Updated python version from 3.4.3 to 3.5.1
    Updated expat version from 2.1.0 to 2.1.1
    Updated llvm / clang version from 3.7.1 to 3.8.0
    Updated make version from 4.1 to 4.2.1
    Build system (32 commits)
    Updates for cbfstool / fmap changes
    Order per-region files to optimize placement success
    Add support for the ADA language and toolchain.
    Utilities (103 commits)
    Lint – Update checkpatch.pl, add tools  to find non-ascii & unprintable chars and to verify a single newline at the end of files
    cbfstool – Update for Linux payloads, Honor FSP modules addresses, fix elf parsing
    Sconfig – Add 10 bit addressing mode for i2c devices, add generic device type, support strings, pass in devicetree filename
    General code cleanup (197 commits)
    Cleaning up code formatting and whitespace
    Fix spelling & capitalization
    Removing commented out code
    Transition away from device_t
    TPM (55 commits)
    Add support for Trusted Platform Module 2.0
    SPI & refactored I2C TPM driver
    Drivers (54 commits)
    Add ACPI support in several drivers
    coreboot_tables –  Extend serial port description
    Elog – refactor, add debug info
    I2C – add generic driver,
    SPI – Add new chip support, major refactoring, don’t assume SPI flash boot device
    Lib (33 commits)
    Add real-time-clock functions
    Add RW boot device construct
    reg_script updates: add to bootblock, add xor support, add display support
    Timestamp fixes & updates
    Vendorcode
    AMD (14 commits) – Cleanup, add libagesa.a builds, remove unused code.
    Google (22 commits) – VBoot2 updates and cleanup
    Intel (86 commits) – Add Intel FSP 2.0, update Broadwell DE support
    Payloads (37 commits)
    Subpayload support got extend and is enabled by default.
    nvramcui: refactor, update build
    SeaBIOS: Update stable version to 1.9.3, add bootorder file
    iPXE: Update stable version to the last commit of July 2016
    Fix broken linux boot sequence
  Mainboard changes
  Added 13 mainboards, plus a few mainboard variants not included here:
    ADI RCC-DFF networking board (adi/rcc-dff) – intel/rangeley SoC
    AMD Evaluation Board DB-FT3B-LC (amd/db-ft3b-lc) – amd/00730F01 (Family 16h Models 30h-3Fh (Mullins)) CPU
    AMD f2950 / TONK 1201/2 Board (amd/f2950) – amd/geode_lx CPU
    Apple iMAC 5.2 (apple/imac52) – intel/i945 CPU
    Unibap Development Kit ODE E21XX – amd/00730F01 (Family 16h Models 30h-3Fh (Mullins)) CPU
    elmex/pcm205400 – amd/Family_14 CPU
    elmex/pcm205401 – amd/Family_14 CPU
    Lenovo N21 chromebook (google/enguarde) – intel/baytrail SoC
    google/gale – Qualcomm IPQ40XX SoC
    AOpen Chromebox (google/ninja) – intel/baytrail SoC
    google/reef – intel/apollolake SoC
    Acer Chromebox CXI2 (google/rikku) – intel/Broadwell SoC
    google/rotor – marvell/MVMAP2315 SoC
  Removed 5 mainboards:
  These were all development boards not available to the public.
    google/bolt – intel/haswell – removed in commit 139314b
    google/rush – nvidia/tegra132 – removed in commit e67cd9e
    google/rush_ryu – nvidia/tegra132 – removed in commit 0c63415
    google/slippy – intel/haswell – removed in commit bc24b85
    intel/amenia – intel/apollolake – removed in commit c2586db
  Existing boards with significant updates
    asus/kgpe-d16 – amd/socket_G34 – Add TPM support, enable secondary serial port
    emulation/spike-riscv: RISC-V -clean up, use generic bootblock,  look for CBFS in RAM, reimplement SBI
    google/gru – rockchip/RK3399 SoC (76 commits) – Board bringup
    google/oak – mediatek/mt8173 SoC- Add Elm variant, update memory, configure display, initialize touchscreen gpio
    intel/galilleo- intel/quark SoC (14 commits) – Board bringup, add galileo gen1 support, switch to FSP2.0
    intel/minnowmax – intel/fsp_baytrail SoC – Enable all PCIe ports, Program GPIO for power LED
    lenovo/x60 – intel/socket_mPGA478 – init GPIOs before dock check, add hda verb table
    siemens/mc_bdx1 – intel/fsp_broadwell_de SoC – Add external RTC, Set up MAC addresses, Update IRQs
    siemens/mc_tcu3 – intel/fsp_baytrail SoC – cleanup & LCD panel updates
  Changes in chips
  Moved 3 northbridge/southbridge pairs to soc:
    dmp/vortex86ex
    intel/sch
    rdc/r8610
  Added 2 socs:
    marvell/mvmap2315 (12 commits)
    qualcomm/ipq40xx (22 commits)
  Removed 1 soc:
    nvidia/tegra132 – removed in commit 9ba0699
  Added 2 sios:
    nuvoton/nct6776
    nuvoton/nct6791d
  Existing chip areas with many changes
    ARM (34 commits)
    Add armv7-r configuration
    rockchip/rk3399 (73 commits) – Bringup, memory updates
    RISC-V (40 commits)
    Improve and refactor trap handling
    X86 (225 commits)
    ACPI (40 commits) Add support for writing various entries and descriptor types, Add common definitions, Use ‘GOOG’ id for coreboot table
    amd/mct_ddr3 northbridge: Support non-ECC DIMMs, Update SMBIOS, various fixes
    arch/x86: many postcar stage updates, add common ACPI definitions, Support “weak” BIST and timestamp save routines
    intel/apollolake SoC (211 commits) – Chip bringup, Update bootblock
    intel/common: ACPI updates, Add smihandler, LPSS I2C driver, and  IGD OpRegion support
    intel/fsp_broadwell_de: IRQ fixes, SPI message fixes, Add DMAR table to ACPI
    intel/gm45 northbridge: Fix text mode init, enable vesa framebuffer, use VGA if connected
    intel/i945 northbridge: add native VGA init, Update divisor calculations
    intel/quark SoC (62 commits) – Chip bringup, add Fsp2.0 support, updates for serial console
    intel/skylake CPU (61 commits) – Finished Skylake bringup, start updating for Kabylake FSP
    intel/x4x northbridge (13 commits) – Memory & Graphics updates
* Sun Feb  7 2016 mpluskal@suse.com
- Update to 4.3
  * cleanups and improvements to many of the utilities
  * cbfstool: Many fixes and extensions to integrate with FMAP
  * Add amdfwtool to combine AMD firmware blobs instead of using
    shell scripts.
* Sun Dec  6 2015 p.drouand@gmail.com
- Use upstream tarball instead of svn revisions
  version 4.2
- Remove obsolete patches
  * nvramtool-revision.diff
  * superiotool-revision.diff
- Remove update-snapshots.sh
- Use download Url as source
* Wed Mar 13 2013 cfarrell@suse.com
- license update: GPL-2.0
  No indication of aggregation
* Mon Feb  4 2013 coolo@suse.com
- update license to new format
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Thu Dec  9 2010 stepan@coresystems.de
- update to r6158
- add coreboot utilities:
  * inteltool
  * superiotool
  * ectool
  * msrtool
  * k8resdump et al
  * cbfstool
- split off flashrom into separate package
* Wed Sep  2 2009 kernel01@hailfinger.org
- Update flashrom to from 0.9.1-rc1 to 0.9.1
  * Bug fixes and documentation fixes only
- Update nvramtool to r4625
  * Fix HIGH_TABLES
  * Install manpage in section 8 instead of section 1
* Mon Aug 24 2009 kernel01@hailfinger.org
- Update flashrom description
- Add nvramtool description
- Use RPM_OPT_FLAGS, drop custom CFLAGS/LDFLAGS
- Install nvramtool in sbin because it's only usable as root
* Tue Aug 18 2009 kernel01@hailfinger.org
- Update flashrom to version 0.9.1-rc1
  * Support for more external flashers
  * Universal external flasher protocol
  * Automatic write/erase verification
  * Dozens of added flash chips, chipsets, mainboards
  * No root privileges needed for most external flashers
  * Improved more verbose user interface
  * Speedups: Fast bus type dependent probing, 100x faster write for
  some chips
  * Reliability fixes for buggy hardware, corner case spec
  conformance
* Mon Jun 22 2009 trenn@suse.de
- Update coreboot-utils to version 0.9.0
* Thu Jan  8 2009 bbrunner@suse.de
- update nvramtool to svn release r3852
- update flashrom to svn release r3852
* Wed Oct 15 2008 bwalle@suse.de
- update nvramtool to svn release r3613
- update flashrom to svn release r3659
* Wed Aug 13 2008 ro@suse.de
- add ExclusiveArch
* Mon Mar 17 2008 bwalle@suse.de
- rename lxbios to nvramtool
- update nvramtool to svn release r3124
- update flashrom to svn release r3153
* Sat Jan 19 2008 bwalle@suse.de
- update to svn release r3061
  o Support SPI flash chips bigger than 512 kByte sitting behind
    IT8716F Super I/O performing LPC-to-SPI flash translation.
  o Enable MX25L8005 support in flashrom.
  o Minor changes.
- add lxbios utility
* Thu Jan 10 2008 bwalle@suse.de
- initial package
